TokioIo

Trait TokioIo 

pub trait TokioIo { }
Trait indicating that tokio IO can be used with the executor that implements it. Currently this can be enabled through features on TokioCt, TokioTp, AsyncGlobal and AsyncStd.

This means a tokio reactor will be running and that the network types from tokio (eg. TcpStream) will work.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl TokioIo for TokioTp

Available on crate feature tokio_io only.