[−][src]Trait async_executors::SpawnHandleExt
Convenience trait for passing in a generic future to SpawnHandle. Much akin to Spawn and SpawnExt in the
futures library.
Required methods
pub fn spawn_handle(
&self,
future: impl Future<Output = Out> + Send + 'static
) -> Result<JoinHandle<Out>, SpawnError>[src]
&self,
future: impl Future<Output = Out> + Send + 'static
) -> Result<JoinHandle<Out>, SpawnError>
Spawn a future and return a JoinHandle that can be awaited for the output of the future.
Implementors
impl<T: ?Sized, Out> SpawnHandleExt<Out> for T where
T: SpawnHandle<Out>,
Out: 'static + Send, [src]
T: SpawnHandle<Out>,
Out: 'static + Send,
pub fn spawn_handle(
&self,
future: impl Future<Output = Out> + Send + 'static
) -> Result<JoinHandle<Out>, SpawnError>[src]
&self,
future: impl Future<Output = Out> + Send + 'static
) -> Result<JoinHandle<Out>, SpawnError>